﻿// (c) 2013 Cesys GmbH
// Author: Thomas Hoppe
using System;
using System.Collections.Generic;
using System.Text;

namespace CeboMsrNet
{
    /// <summary>
    /// These objects are used to set the range of analog inputs and outputs.
    /// Direct construction is not possible, SupportedRanges of AnalogInput and
    /// AnalogOutput can be used to request the possible ranges of an input or output.
    /// </summary>
    public sealed class Range
    {
        private uint _interfaceId;
        private float _minValue, _maxValue;
        private int _defaultInterChannelDelay;

        internal uint InterfaceId { get { return _interfaceId; } }
        internal int DefaultInterChannelDelay { get { return _defaultInterChannelDelay; } }

        internal Range(uint interfaceId, float minValue, float maxValue, int defaultInterChannelDelay)
        {
            _interfaceId = interfaceId;
            _minValue = minValue;
            _maxValue = maxValue;
            _defaultInterChannelDelay = defaultInterChannelDelay;
        }

        /// <summary>
        /// Lower voltage.
        /// </summary>
        public float MinValue { get { return _minValue; } }

        /// <summary>
        /// Upper voltage.
        /// </summary>
        public float MaxValue { get { return _maxValue; } }

        public override string ToString()
        {
            return "Range: " + _minValue + "V - " + _maxValue + "V";
        }
    }
}
