package com.cesys.cebo.cebomsr;

import java.io.IOException;

/**
 * Offers functionality for current sources. Instances can be retrieved using
 * getCurrentSources() of the respective {@link Device} instance.
 *
 * @author Thomas Hoppe
 */
public final class CurrentSource {
	private final Device _device;
	private final int _interfaceId;
	private final String _name;

	int getInterfaceId() {
		return _interfaceId;
	}

	CurrentSource(Device device, int interfaceId, int index) throws IOException {
		_device = device;
		_interfaceId = interfaceId;
		byte[] tmp = new byte[SystemConnector.MaxIdentLength];
		SystemConnector.checkError(SystemConnector.CeboMsrGetPeripheralName(device.getHandle(), interfaceId, tmp));
		_name = Utils.convertByteArrayToString(tmp);
	}

	/**
	 * Returns the real current of the constant current source in micro ampere.
	 */
	public float getReferenceCurrent() throws IOException {
		float[] r = new float[1];
		SystemConnector.checkError(SystemConnector.CeboMsrGetReferenceCurrent(_device.getHandle(), getInterfaceId(), r));
		return r[0];
	}

	/**
	 * Returns name of the component.
	 */
	public String getName() {
		return _name;
	}

	@Override
	public String toString() {
		return "CurrentSource: " + _name;
	}
}
